import Vue, { VueConstructor } from 'vue'
import { LooseDictionary } from './ts-helpers'

export interface QWindow extends Vue {
    /**
     * `v-model`; Controls visibility of the window
     */
    value? : boolean
    /**
     * The title for the titlebar
     */
    title? : string
    /**
     * Makes the titlebar height more dense
     */
    dense? : boolean
    /**
     * If the QWindow should be initially embedded
     */
    embedded? : boolean
    /**
     * If the QWindow should be initially pinned
     */
    pinned? : boolean
    /**
     * If the QWindow should initially be fullscreen
     */
    fullscreen? : boolean
    /**
     * If the QWindow should be initially maximized
     */
    maximized? : boolean
    /**
     * If the QWindow should be initially minimized
     */
    minimized? : boolean
    /**
     * Prevent the titlebar from drawing the menu (see [No Menu](/examples#No-Menu) example)
     */
    noMenu? : boolean
    /**
     * Restricts the ability to `move` the QWindow. Moving can still be accomplished by resizing unless you restrict using the `resizable` property
     */
    noMove? : boolean
    /**
     * Restricts the ability to `resize` the QWindow
     */
    noResize? : boolean
    /**
     * Contains an array of resize handle names that are allowed
     */
    resizable? : StringArray
    /**
     * When the document body is scrolled, the QWindow will scroll with it. Normal behavior is to 'stay-in-place'
     */
    scrollWithWindow? : boolean
    /**
     * QWindow will manage grippers depending on selected state
     */
    autoPin? : boolean
    /**
     * If true, the QWindow will be in a disabled state
     */
    disabled? : boolean
    /**
     * If the QWindow toolbar divider should be displayed
     */
    hideToolbarDivider? : boolean
    /**
     * If the QWindow grippers should be hidden
     */
    hideGrippers? : boolean
    /**
     * If the QWindow grippers should be round instead of square
     */
    roundGrippers? : boolean
    /**
     * Prevent titlebar from being drawn (see Headless example)
     */
    headless? : boolean
    /**
     * Allows icons and language to be changed. This is the menu definition which is modified and converted to a menu object for display purposes (see `menu-func`)
     */
    iconSet? : {
            /**
             * Key for the object
             */
            identifier? : {
                    /**
                     * The `on` key identifier is used when the state is `true`
                     */
                    on? : {
                            /**
                             * The icon to display based on state is `true` (can be empty)
                             */
                            icon? : string
                            /**
                             * The label to display based on state is `true`
                             */
                            label? : string }
                    /**
                     * The `off` key identifier is used when the state is `false`
                     */
                    off? : {
                            /**
                             * The icon to display based on state is `false` (can be empty)
                             */
                            icon? : string
                            /**
                             * The label to display based on state is `false`
                             */
                            label? : string } } }
    /**
     * The initial starting X position (in px)
     */
    startX? : number | string
    /**
     * The initial starting Y position (in px)
     */
    startY? : number | string
    /**
     * The initial starting width size (in px)
     */
    width? : number | string
    /**
     * The initial starting height size (in px)
     */
    height? : number | string
    /**
     * The actions that can be applied to the QWindow
     */
    actions? : any[]
    /**
     * Any color from the [Quasar Color Pallete](https://quasar.dev/style/color-palette) or any CSS color
     */
    color? : string
    /**
     * Any color from the [Quasar Color Pallete](https://quasar.dev/style/color-palette) or any CSS color
     */
    backgroundColor? : string
    /**
     * Any color from the [Quasar Color Pallete](https://quasar.dev/style/color-palette) or any CSS color
     */
    gripperBorderColor? : string
    /**
     * Any color from the [Quasar Color Pallete](https://quasar.dev/style/color-palette) or any CSS color
     */
    gripperBackgroundColor? : string
    /**
     * Allows the menu to me modified before being displayed
     */
    menuFunc? : Function
    /**
     * This can be any CSS unit (including unit)
     */
    borderWidth? : string
    /**
     * This can be any CSS border style
     */
    borderStyle? : string
    /**
     * Style definitions to be attributed to the titlebar
     */
    titlebarStyle? : string | LooseDictionary | any[]
    /**
     * Class definitions to be attributed to the titlebar
     */
    titlebarClass? : string | LooseDictionary | any[]
    /**
     * Style definitions to be attributed to the content
     */
    contentStyle? : string | LooseDictionary | any[]
    /**
     * Class definitions to be attributed to the content
     */
    contentClass? : string | LooseDictionary | any[]
    /**
     * Makes the QWindow visible
     */
    show (): void
    /**
     * Makes the QWindow hidden
     */
    hide (): void
    /**
     * Makes the QWindow embedded
     */
    lock (): void
    /**
     * Makes the QWindow floating
     */
    unlock (): void
    /**
     * Makes the QWindow pinned (fixed at location)
     */
    pin (): void
    /**
     * Makes the QWindow non-pinned (movable, resizable, etc)
     */
    unpin (): void
    /**
     * Makes the QWindow maximized
     */
    maximize (): void
    /**
     * Makes the QWindow minimized
     */
    minimize (): void
    /**
     * Restores the QWindow (from maximized)
     */
    restore (): void
    /**
     * Makes the QWindow enter fullscreen
     */
    fullscreenEnter (): void
    /**
     * Makes the QWindow leave fullscreen
     */
    fullscreenLeave (): void
    /**
     * Toggles the QWindow fullscreen state
     */
    toggleFullscreen (): void
    /**
     * Brings the QWindow to the front layer
     */
    bringToFront (): void
    /**
     * Send the QWindow to the back layer
     */
    sendToBack (): void
    /**
     * Centers the QWindow on the visible view port
     */
    centerWindow (): void
    /**
     * Programmatically set the x position
     * @param x The x position
     */
    setX (x? : number): void
    /**
     * Programmatically set the y position
     * @param y The y position
     */
    setY (y? : number): void
    /**
     * Programmatically set both the x and y positions
     * @param x The x position
     * @param y The y position
     */
    setXY (x? : number, y? : number): void
    /**
     * Programmatically set the QWindow width
     * @param width The width
     */
    setWidth (width? : number): void
    /**
     * Programmatically set the QWindow height
     * @param height The height
     */
    setHeight (height? : number): void
    /**
     * Pass in an action, like `embedded` or `close` and will return true or false if it can be done at this time. Useful for determining items in the menu
     * @param state The action to test against
     * @returns true if the passed in action can be done at this time otherwise false
     */
    canDo (state? : string): boolean
}

import { StringArray } from './types'

declare module 'vue/types/vue' {
    interface Vue {
    }
}
export * from './types'
export * from './ts-helpers'
export as namespace QWindow
export const QWindow: VueConstructor<QWindow>

